@@ -5,12 +5,12 @@ set -v
 
 if [ "$TRAVIS_OS_NAME" = linux ]; then
     cd $TRAVIS_BUILD_DIR
-    docker build -f .travis/Dockerfile .
+    docker build . -t ${TARGET} -f .travis/${TARGET}.docker
 fi
 
 if [ "$TRAVIS_OS_NAME" = osx ]; then
     export DYLD_LIBRARY_PATH=$HOME/miniconda/envs/testenv/lib
     export LD_LIBRARY_PATH=$HOME/miniconda/envs/testenv/lib
-    nosetests --with-coverage
+    pytest
     travis-sphinx --nowarn -s doc build
 fi
