@@ -28,7 +28,9 @@
 #ifndef PYRAP_FITTING_H
 #define PYRAP_FITTING_H
 
-namespace casa {
+#include <casacore/casa/aips.h>
+
+namespace casacore {
   namespace python {
     void fit();
   } // python
